Release Notes
=============

.. toctree::
   :maxdepth: 1

   release.0.1.6
   release.0.1.7
   release.0.1.8
   release.0.1.9
   release.0.1.10
   release.0.1.11
   release.0.1.12
   release.0.1.15
   release.0.1.16
   release.0.1.17
   release.0.1.18
   release.0.1.19
   release.0.1.20
   release.0.1.21
   release.0.1.22
   release.0.1.23